% MuDim.m 
% measure the dimensionality of the elements making up body materials
% Use tables of fraction of elements by weight
% see http://www.aprendtech.com/Software/xraymu.zip for
% the functions used here
% REA 2011-05-25 -- 28


%% make the mus table
negys = 100; % number of energies for mus table
xray_energies = linspace(20,150,negys); % negys points from 10 to 150 keV
mus = [];
zs_all = [];
dat = BodyMaterialCompositionFunc; % composition of body materials
for name = {'bone_cortical','soft_tissue'}  
  ztable = dat.(char(name));
  zs_all = [zs_all; ztable(2:end,1)];
  for kelem = 2:size(ztable,1)
    m = xraymu(ztable(kelem,:),xray_energies);
    m = (m - mean(m))/std(m); % standardize to unit std dev
    mus = [mus m(:)];
  end
end
   % throw out the dups
[zuniq,M,N] = unique(zs_all);
mus = mus(:,M);


%% principal values with and without a K-edge--use iodine as high atomic number material
    % principal values of body materials
musc = mus - repmat(mean(mus),size(mus,1),1);  % subtract mean to 'center' the data
[u,s,v] = svd(musc,'econ');
singvals = diag(s);
pcs_all = (1/negys)*singvals.^2; % see eigenvalues of covariance in PCA
pcs = pcs_all(1:5);

   % principal values with iodine
m = xraymu('I',xray_energies);
mus_with_I = [mus (m(:) - mean(m))/std(m)];% add I mu to the previous data
[u,s,v] = svd(mus_with_I,'econ');
singvals = diag(s);
pcsI_all = (1/negys)*singvals.^2; 
pcsI = pcsI_all(1:5);
pcs2 = [pcs/norm(pcs) pcsI/norm(pcsI)];

   % plot the data
fh = figure;
subplot(121)
hb1 = bar(pcs2,0.6,'group'); % 0.2 = bar width
title('\mu principal values','fontsize',16)
set(gca,'fontsize',12)
colormap autumn
legend('bio-only','w/iodine')

subplot(122)
  % log plot of principal components
hb2 = bar(pcs2,0.6,'group'); % 0.6 = bar width
set(gca,'yscale','log','fontsize',12)
vax = axis;
set(hb2,'basevalue',vax(3)) % draw horizontal axis at bottom
title('log scale','fontsize',14)
set(fh,'color','w','position',[250 1000 650 350]);

%% print the figure as png and eps
dirname = 'E:\Projects\Blog\Posts\P5DimWithSVD\'; % edit this for your computer
figno = sprintf('-f%d',fh);
print(figno,[dirname 'mu_princomp.png'],'-dpng','-cmyk','-r100') % resolution 100 dpi
   % export as eps
print(figno,[dirname 'mu_princomp.eps'],'-deps','-cmyk') 

%% make Pareto plots
frac_rem1 = 1 - cumsum(pcs)/sum(pcs_all);
frac_rem2 = 1 - cumsum(pcsI)/sum(pcsI_all);
fh = figure;
hb3 =bar([frac_rem1 frac_rem2],0.6,'group');
colormap autumn
set(gca,'yscale','log','fontsize',12)
ylabel('fraction remaining','fontsize',12);
xlabel('component number','fontsize',12);
vax = axis;
set(hb3,'basevalue',vax(3)) % draw horizontal axis at bottom
title('fraction of variance vs number of basis functions--log scale','fontsize',14)
legend('bio-only','w/iodine')
set(fh,'color','w','position',[250 1000 550 535])

%% print the figure as png and eps
dirname = 'E:\Projects\Blog\Posts\P5DimWithSVD\'; % edit this for your computer
figno = sprintf('-f%d',fh);
print(figno,[dirname 'frac_vs_dim.png'],'-dpng','-cmyk','-r100') 
   % export as eps
print(figno,[dirname 'frac_vs_dim.eps'],'-deps','-cmyk') 
